==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
export let WebListItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebListItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebListItemDescriptionMetadata.a == null) {
                WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
            }
            if (a.k(WebListItemDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebListItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ListItem");
            a.item("__tagNameWC", "String:igc-list-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebListItemDescriptionMetadata.b(a);
            a.ad("WebListItem", () => new WebListItemDescription());
            a.ac("WebListItem", WebListItemDescriptionMetadata.a);
        }
    }
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebListItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebListItemDescription } from "./WebListItemDescription";
/**
 * @hidden
 */
export let WebListItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebListItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebListItemDescriptionMetadata.a == null) {
                WebListItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebListItemDescriptionMetadata.c(WebListItemDescriptionMetadata.a);
            }
            if (a.k(WebListItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebListItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:ListItem");
            a.item("__tagNameWC", "String:igc-list-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("Selected", "Boolean");
        }
        static d(a) {
            WebListItemDescriptionMetadata.b(a);
            a.ae("WebListItem", () => new WebListItemDescription());
            a.ad("WebListItem", WebListItemDescriptionMetadata.a);
        }
    }
    WebListItemDescriptionMetadata.$t = markType(WebListItemDescriptionMetadata, 'WebListItemDescriptionMetadata');
    WebListItemDescriptionMetadata.a = null;
    return WebListItemDescriptionMetadata;
})();
